use serde_json::Value;
use std::fmt::{Display, Formatter, Result};

#[derive(Debug)]
pub enum ZabbixStatus {
    High = 4,
    Average = 3,
    Warning = 2,
    Info = 1,
}

#[derive(Debug)]
pub struct ZabbixLayout {
    pub layout: Vec<ZabbixProblems>,
}

impl ZabbixLayout {
    pub fn new() -> Self {
        Self { layout: Vec::new() }
    }
}

#[derive(Debug)]
pub struct ZabbixProblems {
    pub status: i64,
}

impl Display for ZabbixProblems {
    fn fmt(&self, f: &mut Formatter) -> Result {
        write!(f, "status: {:?}", self.status)
    }
}

impl ZabbixLayout {
    pub fn compute(&mut self, input: &Value) {
        self.layout = Vec::new();
        for j in input.as_object().unwrap()["result"].as_array().unwrap() {
            let res = j.as_object().unwrap();
            let severity = res["priority"].as_str().unwrap().parse::<i64>().unwrap();
            self.layout.push(ZabbixProblems { status: severity });
        }
    }
}
